pub struct RustResolutionContext { /* private fields */ }Expand description
Rust-specific resolution context implementing proper scoping rules
Rust has a specific resolution order:
- Local scope (variables, parameters)
- Imported symbols (use statements)
- Module symbols (items in current module)
- Crate symbols (pub items from crate root)
Implementations
Sourceimpl RustResolutionContext
impl RustResolutionContext
pub fn new(file_id: FileId) -> Self
Sourcepub fn add_import(&mut self, path: String, alias: Option<String>)
pub fn add_import(&mut self, path: String, alias: Option<String>)
Add an import (use statement)
Sourcepub fn add_local(&mut self, name: String, symbol_id: SymbolId)
pub fn add_local(&mut self, name: String, symbol_id: SymbolId)
Add a local variable or parameter to the current scope
Sourcepub fn add_import_symbol(
&mut self,
name: String,
symbol_id: SymbolId,
_is_aliased: bool,
)
pub fn add_import_symbol( &mut self, name: String, symbol_id: SymbolId, _is_aliased: bool, )
Add an imported symbol with resolved SymbolId
Sourcepub fn add_module_symbol(&mut self, name: String, symbol_id: SymbolId)
pub fn add_module_symbol(&mut self, name: String, symbol_id: SymbolId)
Add a module-level symbol from the current file
Sourcepub fn add_crate_symbol(&mut self, name: String, symbol_id: SymbolId)
pub fn add_crate_symbol(&mut self, name: String, symbol_id: SymbolId)
Add a crate-level public symbol
Sourcepub fn is_imported(&self, name: &str) -> bool
pub fn is_imported(&self, name: &str) -> bool
Check if a symbol with the given name was imported